@@ -40,11 +40,8 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include <unistd.h>
 #include <stdlib.h>
 
-#include "spadBitmap.bitmap"
-#include "spadMask.mask"
-
 #include "header.h"
-    /*** definition for the axes and labels - this is the minimun that will be
+    /*** definition for the axes and labels - this is the minimum that will be
          drawn on the window - thus allowing the user some idea of the
          orientation of the coordinate axes when rotating, etc. The
          drawing of the mesh is aborted when an appropriate X event occurs.
@@ -628,12 +625,6 @@ makeViewport (void)
   /* Initialize the translation matrix. */
   TRANSLATE(-viewport->deltaX,-viewport->deltaY,0.0,T);
            /**** make the windows for the viewport ****/
-  spadbits = XCreateBitmapFromData(dsply,rtWindow,
-                                   spadBitmap_bits,
-                                   spadBitmap_width,spadBitmap_height);
-  spadmask = XCreateBitmapFromData(dsply,rtWindow,
-                                   spadMask_bits,
-                                   spadMask_width,spadMask_height);
   viewAttrib.background_pixel = backgroundColor;
   viewAttrib.border_pixel = foregroundColor;
 
@@ -648,8 +639,6 @@ makeViewport (void)
 */
   XQueryColor(dsply,colorMap,&foreColor);
   XQueryColor(dsply,colorMap,&backColor);
-  viewAttrib.cursor = XCreatePixmapCursor(dsply,spadbits,spadmask,
-                                          &foreColor,&backColor,spadBitmap_x_hot,spadBitmap_y_hot);
   viewAttrib.event_mask = titleMASK;
   if (viewData.vW) {
     titleSizeHints.flags  = PPosition | PSize;
