@@ -279,7 +279,7 @@ typedef struct button_list {
   struct button_list    *next;
 } ButtonList;
 
-/* Stucture for unformatted hyper text page */
+/* Structure for unformatted hyper text page */
 
 typedef struct hyperdoc_page {
   short type;                   /* Normal, Quitbutton, Upbutton etc.       */
@@ -343,7 +343,7 @@ typedef struct {
                                 /*        button                         */
   int scrolldowny;              /* Current y position of the scroll      */
                                 /*        downbutton                     */
-  int scrollbary;               /* Current y position of teh scrollbar   */
+  int scrollbary;               /* Current y position of the scrollbar   */
   int scrollx;                  /* X coordinates for all of the above    */
   int border_width;             /* Width of the border                   */
   HyperDocPage *page;           /* currently displayed page              */
@@ -409,7 +409,7 @@ extern HashTable gImageHashTable;           /* A global hash table for images */
 extern Cursor gNormalCursor;          /* The normal mouse cursor                */
 extern Cursor gActiveCursor;          /* The cursor in active regions           */
 extern Cursor gBusyCursor;            /* The clock cursor for when I am busy    */
-/* true iff HyperDoc is acting as an FriCAS server */
+/* true iff HyperDoc is acting as a FriCAS server */
 extern int is_fricas_server;
 extern int    gArgc;                  /* original argc from main */
 extern char **gArgv;                  /* original argv from main */
