@@ -346,7 +346,7 @@ database.
   (|Fraction| . |Algebra|) (|Fraction| . |CoercibleTo|)
   (|Fraction| . |OrderedSet|) (|Fraction| . |RetractableTo|)
   (|Integer| . |Algebra|) (|Integer| . |CoercibleTo|)
-  (|Integer| . |ConvertibleTo|) (|Integer| . |LinearlyExplicitRingOver|)
+  (|Integer| . |ConvertibleTo|) (|Integer| . |LinearlyExplicitOver|)
   (|Integer| . |RetractableTo|)
   (|List| . |CoercibleTo|) (|List| . |FiniteLinearAggregate|)
   (|List| . |OrderedSet|)
@@ -392,7 +392,7 @@ database.
   |UnivariatePolynomialCategory&| |FlexibleArray|
   |SparseMultivariatePolynomial| |PolynomialCategory&|
   |DifferentialExtension&| |IndexedFlexibleArray| |AbelianMonoidRing&|
-  |FiniteAbelianMonoidRing&| |DivisionRing&| |FullyLinearlyExplicitRingOver&|
+  |FiniteAbelianMonoidRing&| |DivisionRing&| |FullyLinearlyExplicitOver&|
   |IndexedVector| |IndexedOneDimensionalArray| |LocalAlgebra| |Localize|
   |Boolean| |Field&| |Vector| |IndexedDirectProductObject| |Aggregate&|
   |PolynomialRing| |FreeModule| |IndexedDirectProductAbelianGroup|
@@ -516,7 +516,7 @@ database.
     (setq item (unsqueeze item))
     (unless (setq dbstruct (get (car item) 'database))
      (format t "browseOpen:~%")
-     (format t "the browse database contains a contructor ~a~%" item)
+     (format t "the browse database contains a constructor ~a~%" item)
      (format t "that is not in the interp.daase file. we cannot~%")
      (format t "get the database structure for this constructor and~%")
      (warn "will create a new one~%")
@@ -909,7 +909,8 @@ database.
    (asharp file)
    (setq file (|astran| (concatenate 'string (pathname-name file) ".asy")))
    (localasy file object only make-database? noexpose))
-  (CLRHASH |$ConstructorCache|))))
+  (|clearConstructorCaches|))
+))
 
 (defun localasy (asy object only make-database? noexpose)
  "given an alist from the asyfile and the objectfile update the database"
@@ -1461,7 +1462,7 @@ database.
 
 ; how the magic works:
 ;  when a )library is done on a new compiler file we set up multiple
-;  functions (refered to as autoloaders). there is an autoloader
+;  functions (referred to as autoloaders). there is an autoloader
 ;  stored in the symbol-function of the G-filename (e.g. G-basic)
 ;  (see set-file-getter function)
 ;  and an autoloader stored in the symbol-function of every domain
