@@ -227,8 +227,8 @@
 (defmacro |CharNE|    (x y) `(CHAR/= (the |Char| ,x) (the |Char| ,y)))
 (defmacro |CharLower|   (x) `(the |Char| (CHAR-DOWNCASE (the |Char| ,x))))
 (defmacro |CharUpper|   (x) `(the |Char| (CHAR-UPCASE (the |Char| ,x))))
-(defmacro |CharOrd|     (x) `(CHAR-INT (the |Char| ,x)))
-(defmacro |CharNum|     (x) `(INT-CHAR (the |SInt| ,x)))
+(defmacro |CharOrd|     (x) `(CHAR-CODE (the |Char| ,x)))
+(defmacro |CharNum|     (x) `(CODE-CHAR (the |SInt| ,x)))
 
 (defmacro |SFlo0|        () 0.0s0)
 (defmacro |SFlo1|        () 1.0s0)
@@ -799,8 +799,8 @@
     (if (null type)
         (setq path (make-pathname :directory dir :name name :type "as")))
     (if opts
-        (OBEY (format nil "axiomxl ~A -Flsp ~A" opts (namestring path)))
-        (OBEY (format nil "axiomxl -Flsp ~A" (namestring path))))
+        (OBEY (format nil "aldor ~A -Flsp ~A" opts (namestring path)))
+        (OBEY (format nil "aldor -Flsp ~A" (namestring path))))
     (compile-file (namestring lpath))
     (load (namestring cpath))))
 
