@@ -324,16 +324,6 @@
 
 ; 15.2 Lists
 
-(defun ELEMN (X N DEFAULT)
-  (COND ((NULL X) DEFAULT)
-        ((EQL N 1) (CAR X))
-        ((ELEMN (CDR X) (- N 1) DEFAULT))))
-
-(defun LISTOFATOMS (X)
-  (COND ((NULL X) NIL)
-        ((ATOM X) (LIST X))
-        ((NCONC (LISTOFATOMS (CAR X)) (LISTOFATOMS (CDR X))))))
-
 (DEFUN LASTATOM (L) (if (ATOM L) L (LASTATOM (CDR L))))
 
 (defun DROP (N X &aux m)
@@ -373,27 +363,6 @@
 
 ; 15.5 Using Lists as Sets
 
-;;; The [[CONTAINED]] predicate is used to walk internal structures
-;;; such as modemaps to see if the $X$ object occurs within $Y$. One
-;;; particular use is in a function called [[isPartialMode]] (see
-;;; i-funsel.boot) to decide
-;;; if a modemap is only partially complete. If this is true then the
-;;; modemap will contain the constant [[$EmptyMode]]. So the call
-;;; ends up being [[CONTAINED |$EmptyMode| Y]].
-(DEFUN CONTAINED (X Y)
-  (if (symbolp x)
-      (contained\,eq X Y)
-      (contained\,equal X Y)))
-
-(defun contained\,eq (x y)
-       (if (atom y) (eq x y)
-           (or (contained\,eq x (car y)) (contained\,eq x (cdr y)))))
-
-(defun contained\,equal (x y)
-   (cond ((atom y) (equal x y))
-         ((equal x y) 't)
-         ('t (or (contained\,equal x (car y)) (contained\,equal x (cdr y))))))
-
 (DEFUN |set_sum| (X Y)
   (COND ((ATOM Y) X)
         ((ATOM X) Y)
@@ -426,7 +395,7 @@
         ((CONS (CAR L) (ADDASSOC X Y (CDR L))))))
 
 (DEFUN DELLASOS (U V)
-  "Remove any assocation pair (U . X) from list V."
+  "Remove any association pair (U . X) from list V."
   (COND ((ATOM V) NIL)
         ((EQUAL U (CAAR V)) (CDR V))
         ((CONS (CAR V) (DELLASOS U (CDR V))))))
@@ -462,7 +431,7 @@
 
 ;;; Operations on Association Sets (AS)
 
-(defun AS-INSERT (A B L)
+(defun AS_INSERT (A B L)
     (let ((pp (assoc A L :test #'equal)))
         (if pp
             (progn
@@ -489,12 +458,8 @@
 
 (defun |get_lisp_error_out| () *error-output*)
 
-(defparameter |$fricasOutput| (make-synonym-stream '*standard-output*))
-
 (defvar |$fortranOutputStream|)
 
-(defvar |$formulaOutputStream|)
-
 (defvar |$highlightAllowed| nil "Used in BRIGHTPRINT and is a )set variable.")
 
 (defvar |$highlightFontOn| (concat " " |$boldString|)
@@ -535,7 +500,7 @@
 
 ; 25 MISCELLANEOUS FEATURES
 
-(defun MAKE-REASONABLE (Z)
+(defun MAKE_REASONABLE (Z)
    (if (> (length Z) 30) (CONCAT "expression beginning " (subseq Z 0 20)) Z))
 
 (defun DROPTRAILINGBLANKS  (LINE)
@@ -608,13 +573,6 @@
 (DEFUN |rightBindingPowerOf| (X IND &AUX (Y (GET X IND)))
    (IF Y (ELEMN Y 4 105) 105))
 
-(defun |make_BF| (MT EP) (LIST |$BFtag| MT EP))
-
-(defun |make_float| (int frac fraclen exp)
-    (if (= frac 0)
-          (|make_BF| int exp)
-          (|make_BF| (+ (* int (expt 10 fraclen)) frac) (- exp fraclen)) ))
-
 (defun |print_full2| (expr stream)
    (let ((*print-circle* t) (*print-array* t) *print-level* *print-length*)
      (print expr stream)
@@ -624,57 +582,45 @@
 
 ;; moved here from preparse.lisp
 
-(defun NEXT-TAB-LOC (i) (* (1+ (truncate i 8)) 8))
+(defvar tab-size-in-spaces 8
+  "How many spaces do we consider a #\Tab character?")
 
-(defun INDENT-POS (STR)
-  (do ((i 0 (1+ i))
-       (pos 0))
-      ((>= i (length str)) nil)
-      (case (char str i)
-            (#\space (incf pos))
-            (#\tab (setq pos (next-tab-loc pos)))
-            (otherwise (return pos)))))
+(defun NEXT-TAB-LOC (i)
+  "Given a character position I, on what position would a #\Tab land
+us?"
+  (* tab-size-in-spaces (1+ (truncate i tab-size-in-spaces))))
 
-;;(defun expand-tabs (str)
-;;  (let ((bpos (nonblankloc str))
-;;      (tpos (indent-pos str)))
-;;    (if (eql bpos tpos) str
-;;      (concatenate 'string (make-string tpos :initial-element #\space)
-;;                 (subseq str bpos)))))
-(defun expand-tabs (str)
-   (if (and (stringp str) (> (length str) 0))
-      (let ((bpos (nonblankloc str))
-            (tpos (indent-pos str)))
-        (setq str
-              (if (eql bpos tpos)
-                  str
-                  (concatenate 'string
-                               (make-string tpos :initial-element #\space)
-                               (subseq str bpos))))
-        (loop
-            (let ((tloc (tabloc str)))
-                (if (null tloc) (return))
-                (let ((rloc (NEXT-TAB-LOC tloc)))
-                    (if (eql tloc rloc)
-                        (setf (aref str tloc) #\Space)
-                        (setf str
-                            (concatenate 'string
-                                (subseq str 0 tloc)
-                                (make-string (+ 1 (- rloc tloc))
-                                    :initial-element #\space)
-                                (subseq str (+ 1 tloc))))))))
-         ;; remove dos CR
-        (let ((lpos (maxindex str)))
-          (if (eq (char str lpos) #\Return) (subseq str 0 lpos) str)))
-    str))
+(defun EXPAND_TABS (str)
+  "Given a string STR, expand all #\Tab characters to spaces, minding
+the correct column each #\Tab would carry us to.
 
-(defun blankp (char) (or (eq char #\Space) (eq char #\tab)))
-
-(defun nonblankloc (str) (position-if-not #'blankp str))
-
-(defun tabp (c) (equal c #\tab))
-
-(defun tabloc (str) (position-if #'tabp str))
+This function respects intermediate #\Newline characters and drops
+#\Return characters."
+  (cond
+    ((stringp str)
+     (with-output-to-string (s)
+       (loop :with column := 0
+             :for c :across str
+             :do (case c
+                   (#\Tab
+                    ;; How many spaces does our tab carry us forward
+                    ;; by?
+                    (let ((num-spaces (- (next-tab-loc column) column)))
+                      (incf column num-spaces)
+                      ;; This format string just writes something N
+                      ;; times without consing up garbage.
+                      (format s "~v@{~C~:*~}" num-spaces #\Space)))
+                   (#\Newline
+                    (setf column 0)
+                    (write-char #\Newline s))
+                   (#\Return
+                    ;; Drop this character completely.
+                    nil)
+                   (t
+                    (incf column)
+                    (write-char c s))))))
+    (t
+     str)))
 
 ;; stream handling for paste-in generation
 
@@ -684,7 +630,7 @@
   (let* ((*standard-output* (make-string-output-stream))
          (curoutstream *standard-output*)
          (*error-output* *standard-output*)
-         (|$algebraOutputStream| *standard-output*)
+         (|$algebraOutputStream| (CONS NIL *standard-output*))
         val)
     (declare (special curoutstream
                       |$algebraOutputStream|))
@@ -750,7 +696,7 @@
 ; NAME:    Debugging Package
 ; PURPOSE: Debugging hooks for Boot code
 
-(defun enable-backtrace (&rest arg))
+(defun ENABLE_BACKTRACE (&rest arg))
 
 (defun |adjoin_equal|(x y) (ADJOIN x y :test #'equal))
 
