@@ -41,11 +41,8 @@
 #+(and :GCL :IEEE-FLOATING-POINT)
   (setq system:*print-nans* T)
 
-(setq |$algebraOutputStream|
-      (setq |$fortranOutputStream|
-            (setq |$texOutputStream|
-                  (setq |$formulaOutputStream|
-                        (make-synonym-stream '*standard-output*)))))
+;;; In case 'setvart.boot' does not work...
+(setq |$algebraOutputStream| (|mkOutputConsoleStream|))
 
 (defvar |$frameMessages| nil)
 (defvar |$displayStartMsgs| nil)
