@@ -80,14 +80,6 @@
 
 (defun LOG2 (x) (LOG x 2.0))
 
-; 9.13 Streams
-
-#+GCL
-(defun IS_CONSOLE (stream)
-  (and (streamp stream) (output-stream-p stream)
-       (eq (system:fp-output-stream stream)
-           (system:fp-output-stream *terminal-io*))))
-
 ; 11.0 Operations on Identifiers
 
 ; 11.1 Creation
@@ -470,7 +462,7 @@
 
 ; 17.2 Accessing
 
-(defun string2id-n (cvec sint)
+(defun STRING2ID_N (cvec sint)
   (if (< sint 1)
       nil
       (let ((start (position-if-not #'(lambda (x) (char= x #\Space)) cvec)))
@@ -478,7 +470,7 @@
             (let ((end (or (position #\Space cvec :start start) (length cvec))))
               (if (= sint 1)
                   (intern (subseq cvec start end))
-                  (string2id-n (subseq cvec end) (1- sint))))
+                  (STRING2ID_N (subseq cvec end) (1- sint))))
             0))))
 
 (defun substring (cvec start length)
@@ -609,35 +601,37 @@
 
 ; 27.1 Creation
 
+(defun |get_console_input| () *standard-input*)
+
 (defun MAKE_INSTREAM (filespec)
-   (cond ((numberp filespec) (make-synonym-stream '*standard-input*))
+   (cond
          ((null filespec) (error "not handled yet"))
          (t (open (|make_input_filename| filespec)
                   :direction :input :if-does-not-exist nil))))
 
 (defun MAKE_OUTSTREAM (filespec)
-   (cond ((numberp filespec) (make-synonym-stream '*standard-output*))
+   (cond 
          ((null filespec) (error "not handled yet"))
          (t (open (|make_filename| filespec) :direction :output
                #+(or :cmucl :openmcl :sbcl) :if-exists
                #+(or :cmucl :sbcl) :supersede
                #+:openmcl :ignored))))
 
+(defun |make_out_stream| (filespec) (CONS T (MAKE_OUTSTREAM filespec)))
+
 (defun MAKE_APPENDSTREAM (filespec)
  "fortran support"
  (cond
-  ((numberp filespec) (make-synonym-stream '*standard-output*))
   ((null filespec) (error "MAKE_APPENDSTREAM: not handled yet"))
   ('else (open (|make_filename| filespec) :direction :output
           :if-exists :append :if-does-not-exist :create))))
 
-(defun |mkOutputConsoleStream| ()
-     (make-synonym-stream '*standard-output*))
+(defun |make_append_stream| (filespec)
+    (CONS T (MAKE_APPENDSTREAM filespec)))
 
-(defun SHUT (st) (if #+:GCL(IS_CONSOLE st)
-                     #-:GCL(typep st 'synonym-stream)
-                     st
-                   (if (streamp st) (close st) -1)))
+(defun |mkOutputConsoleStream| () (CONS NIL *standard-output*))
+
+(defun SHUT (st) (if (streamp st) (close st) -1))
 
 (defun EOFP (stream) (null (peek-char nil stream nil nil)))
 
@@ -655,10 +649,8 @@
 
 (defun PLACEP (item) (eq item *read-place-holder*))
 (defun get_read_placeholder() *read-place-holder*)
-(defun VMREAD (st &optional (eofval *read-place-holder*))
-  (read st nil eofval))
-(defun |read_line| (st &optional (eofval *read-place-holder*))
-  (read-line st nil eofval))
+(defun VMREAD (st) (read st nil *read-place-holder*))
+(defun |read_line| (st) (read-line st nil nil))
 
 #+(OR IBCL KCL)
 (defun gcmsg (x)
@@ -752,9 +744,8 @@
              (sb-ext::run-program "/bin/sh"
                     (list "-c" S) :input t :output t :error t))
    #+:win32 (sb-ext::process-exit-code
-             (sb-ext::run-program (make-absolute-filename "/lib/obey.bat")
-                    (list S) :input t :output t :error t))
-)
+             (sb-ext::run-program "sh"
+                    (list "-c" S) :input t :output t :error t :search t)))
 
 #+:openmcl
 (defun OBEY (S)
